linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH v1 1/2] Revert "drm/bridge: anx7625: Use DPI bus type"
@ 2022-05-23  8:46 Robert Foss
  2022-05-23  8:46 ` [PATCH v1 2/2] Revert "dt-bindings:drm/bridge:anx7625: add port@0 property" Robert Foss
  2022-05-23 12:50 ` [PATCH v1 1/2] Revert "drm/bridge: anx7625: Use DPI bus type" Robert Foss
  0 siblings, 2 replies; 7+ messages in thread
From: Robert Foss @ 2022-05-23  8:46 UTC (permalink / raw)
  To: andrzej.hajda, narmstrong, robert.foss, Laurent.pinchart, jonas,
	jernej.skrabec, airlied, daniel, robh+dt, krzysztof.kozlowski+dt,
	xji, hsinyi, sam, tzimmermann, maxime, jose.exposito89,
	dri-devel, devicetree, linux-kernel

This reverts commit a77c2af0994e24ee36c7ffb6dc852770bdf06fb1.
---
 drivers/gpu/drm/bridge/analogix/anx7625.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/bridge/analogix/anx7625.c b/drivers/gpu/drm/bridge/analogix/anx7625.c
index 01f46d9189c1..53a5da6c49dd 100644
--- a/drivers/gpu/drm/bridge/analogix/anx7625.c
+++ b/drivers/gpu/drm/bridge/analogix/anx7625.c
@@ -1623,14 +1623,14 @@ static int anx7625_parse_dt(struct device *dev,
 
 	anx7625_get_swing_setting(dev, pdata);
 
-	pdata->is_dpi = 0; /* default dsi mode */
+	pdata->is_dpi = 1; /* default dpi mode */
 	pdata->mipi_host_node = of_graph_get_remote_node(np, 0, 0);
 	if (!pdata->mipi_host_node) {
 		DRM_DEV_ERROR(dev, "fail to get internal panel.\n");
 		return -ENODEV;
 	}
 
-	bus_type = 0;
+	bus_type = V4L2_FWNODE_BUS_TYPE_PARALLEL;
 	mipi_lanes = MAX_LANES_SUPPORT;
 	ep0 = of_graph_get_endpoint_by_regs(np, 0, 0);
 	if (ep0) {
@@ -1640,8 +1640,8 @@ static int anx7625_parse_dt(struct device *dev,
 		mipi_lanes = of_property_count_u32_elems(ep0, "data-lanes");
 	}
 
-	if (bus_type == V4L2_FWNODE_BUS_TYPE_DPI) /* bus type is DPI */
-		pdata->is_dpi = 1;
+	if (bus_type == V4L2_FWNODE_BUS_TYPE_PARALLEL) /* bus type is Parallel(DSI) */
+		pdata->is_dpi = 0;
 
 	pdata->mipi_lanes = mipi_lanes;
 	if (pdata->mipi_lanes > MAX_LANES_SUPPORT || pdata->mipi_lanes <= 0)
-- 
2.34.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2022-05-23 16:06 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-05-23  8:46 [PATCH v1 1/2] Revert "drm/bridge: anx7625: Use DPI bus type" Robert Foss
2022-05-23  8:46 ` [PATCH v1 2/2] Revert "dt-bindings:drm/bridge:anx7625: add port@0 property" Robert Foss
2022-05-23 12:50   ` Robert Foss
2022-05-23 12:50 ` [PATCH v1 1/2] Revert "drm/bridge: anx7625: Use DPI bus type" Robert Foss
2022-05-23 12:54   ` Robert Foss
2022-05-23 16:05     ` Daniel Vetter
2022-05-23 16:05     ` Robert Foss

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).